==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/cstp/leechcraft_cstp_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>Aufgabe hinzufügen</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>Lokaler Pfad:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>Der Ordner %1 existiert nicht, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>Der Ordner %1 ist nicht lesbar, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>Der Ordner %1 ist nicht schreibbar, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="201"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="208"/>
        <source>Remove all</source>
        <translation>Alle entfernen</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="217"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="224"/>
        <source>Stop</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="231"/>
        <source>Start all</source>
        <translation>Starte alle</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="238"/>
        <source>Stop all</source>
        <translation>Halte alle an</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="250"/>
        <source>File exists</source>
        <translation>Datei existiert</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="251"/>
        <source>File %1 already exists, continue download?</source>
        <translation>Die Datei %1 existiert bereits, möchten Sie den Download trotzdem fortsetzen?</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="core.cpp" line="63"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location filename="core.cpp" line="277"/>
        <source>Could not truncate file </source>
        <translation>Datei konnte nicht gekürzt werden </translation>
    </message>
    <message>
        <location filename="core.cpp" line="412"/>
        <source>%1 (ETA: %2)</source>
        <translation>%1 (ETA: %2)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="424"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation>%1% (%2 von %3 bei %4)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="428"/>
        <source>/s</source>
        <translation>/s</translation>
    </message>
    <message>
        <location filename="core.cpp" line="430"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="core.cpp" line="516"/>
        <source>Could not open file %1: %2</source>
        <translation>Kann Datei %1 nicht öffnen: %2</translation>
    </message>
    <message>
        <location filename="core.cpp" line="575"/>
        <source>Download finished: %1
%2</source>
        <translation>Download fertiggestellt: %1
%2</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation>Untätig</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="213"/>
        <source>Stopped</source>
        <translation>Angehalten</translation>
    </message>
    <message>
        <location filename="task.cpp" line="215"/>
        <source>Finished</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <location filename="task.cpp" line="217"/>
        <source>Running</source>
        <translation>Läuft</translation>
    </message>
    <message>
        <location filename="task.cpp" line="238"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>Der Task ist nicht richtig gestartet</translation>
    </message>
    <message>
        <location filename="task.cpp" line="476"/>
        <source>Error writing to file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>cstpsettings</name>
    <message>
        <location filename="dummyfile.cpp" line="2"/>
        <source>Local settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="3"/>
        <location filename="dummyfile.cpp" line="7"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="4"/>
        <source>Alert about errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="5"/>
        <source>Network settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="8"/>
        <source>Use text transfer mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="9"/>
        <source>Identification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="10"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="11"/>
        <source>Login:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="12"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="13"/>
        <source>Custom user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="14"/>
        <source>Predefined user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="15"/>
        <source>Firefox 3.0.1 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="16"/>
        <source>Internet Explorer 6.0 on Windows XP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="17"/>
        <source>Internet Explorer 7.0 on Windows Vista</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="18"/>
        <source>Internet Explorer 4.0 on Windows 98</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="19"/>
        <source>Internet Explorer 2.0 on Windows 95</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="20"/>
        <source>Konqueror 4.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="21"/>
        <source>SeaMonkey 1.1.11 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="22"/>
        <source>Opera 9.52 on Linux x86_64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="23"/>
        <source>Wget 1.9.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="24"/>
        <source>w3m 0.5.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="25"/>
        <source>Lynx 2.8.7 with OpenSSL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/cstp/leechcraft_cstp_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>Aufgabe hinzufügen</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>Lokaler Pfad:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>Der Ordner %1 existiert nicht, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>Der Ordner %1 ist nicht lesbar, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>Der Ordner %1 ist nicht schreibbar, möchten Sie einen Anderen auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation>%1 ist kein Verzeichnis, willst du ein anderes Auswählen?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="206"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="213"/>
        <source>Remove all</source>
        <translation>Alle entfernen</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="222"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="229"/>
        <source>Stop</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="236"/>
        <source>Start all</source>
        <translation>Starte alle</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="243"/>
        <source>Stop all</source>
        <translation>Halte alle an</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="255"/>
        <source>File exists</source>
        <translation>Datei existiert</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="256"/>
        <source>File %1 already exists, continue download?</source>
        <translation>Die Datei %1 existiert bereits, möchten Sie den Download trotzdem fortsetzen?</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="core.cpp" line="63"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location filename="core.cpp" line="277"/>
        <source>Could not truncate file </source>
        <translation>Datei konnte nicht gekürzt werden </translation>
    </message>
    <message>
        <location filename="core.cpp" line="417"/>
        <source>%1 (ETA: %2)</source>
        <translation>%1 (ETA: %2)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="429"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation>%1% (%2 von %3 bei %4)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="433"/>
        <source>/s</source>
        <translation>/s</translation>
    </message>
    <message>
        <location filename="core.cpp" line="521"/>
        <source>Could not open file %1: %2</source>
        <translation>Kann Datei %1 nicht öffnen: %2</translation>
    </message>
    <message>
        <location filename="core.cpp" line="580"/>
        <source>Download finished: %1
%2</source>
        <translation>Download fertiggestellt: %1
%2</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation>Untätig</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="213"/>
        <source>Stopped</source>
        <translation>Angehalten</translation>
    </message>
    <message>
        <location filename="task.cpp" line="215"/>
        <source>Finished</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <location filename="task.cpp" line="217"/>
        <source>Running</source>
        <translation>Läuft</translation>
    </message>
    <message>
        <location filename="task.cpp" line="238"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>Der Task ist nicht richtig gestartet</translation>
    </message>
    <message>
        <location filename="task.cpp" line="476"/>
        <source>Error writing to file %1: %2</source>
        <translation>Fehler beim Schreiben in Datei %1: %2</translation>
    </message>
</context>
<context>
    <name>cstpsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Local settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <location filename="dummy.cpp" line="7"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Alert about errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Network settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="8"/>
        <source>Use text transfer mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="9"/>
        <source>Identification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="10"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="11"/>
        <source>Login:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="12"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="13"/>
        <source>Custom user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="14"/>
        <source>Predefined user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="15"/>
        <source>Firefox 3.0.1 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="16"/>
        <source>Internet Explorer 6.0 on Windows XP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="17"/>
        <source>Internet Explorer 7.0 on Windows Vista</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="18"/>
        <source>Internet Explorer 4.0 on Windows 98</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="19"/>
        <source>Internet Explorer 2.0 on Windows 95</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="20"/>
        <source>Konqueror 4.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="21"/>
        <source>SeaMonkey 1.1.11 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="22"/>
        <source>Opera 9.52 on Linux x86_64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="23"/>
        <source>Wget 1.9.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="24"/>
        <source>w3m 0.5.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="25"/>
        <source>Lynx 2.8.7 with OpenSSL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
